// The module 'vscode' contains the VS Code extensibility API
// Import the module and reference it with the alias vscode in your code below
import * as vscode from 'vscode';

// This method is called when your extension is activated
// Your extension is activated the very first time the command is executed
export function activate(context: vscode.ExtensionContext) {

	let disposable = vscode.commands.registerCommand('extension.selectLineNumberStyle', () => {
        const lineNumberStyles = [
            { label: 'Off', description: 'No line numbers.', value: vscode.TextEditorLineNumbersStyle.Off },
            { label: 'On', description: 'Show line numbers.', value: vscode.TextEditorLineNumbersStyle.On },
            { label: 'Relative', description: 'Show line numbers relative to the cursor position.', value: vscode.TextEditorLineNumbersStyle.Relative },
            { label: 'Interval', description: 'Show line numbers at intervals.', value: vscode.TextEditorLineNumbersStyle.Interval }
        ];

        vscode.window.showQuickPick(lineNumberStyles, {
            placeHolder: 'Select a line numbers style'
        }).then(selection => {
            if (!selection) {
                return;
            }

            const activeEditor = vscode.window.activeTextEditor;
            if (activeEditor) {
                activeEditor.options.lineNumbers = selection.value;
            }
        });
    });

    context.subscriptions.push(disposable);
}

// This method is called when your extension is deactivated
export function deactivate() {}
